<?php

namespace Litepci\Compliancetype\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepci\Compliancetype\Models\Version;

class VersionPolicy
{

    /**
     * Determine if the given user can view the version.
     *
     * @param UserPolicy $user
     * @param Version $version
     *
     * @return bool
     */
    public function view(UserPolicy $user, Version $version)
    {
        if ($user->canDo('compliancetype.version.view') && $user->isAdmin()) {
            return true;
        }

        return $version->user_id == user_id() && $version->user_type == user_type();
    }

    /**
     * Determine if the given user can create a version.
     *
     * @param UserPolicy $user
     * @param Version $version
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('compliancetype.version.create');
    }

    /**
     * Determine if the given user can update the given version.
     *
     * @param UserPolicy $user
     * @param Version $version
     *
     * @return bool
     */
    public function update(UserPolicy $user, Version $version)
    {
        if ($user->canDo('compliancetype.version.edit') && $user->isAdmin()) {
            return true;
        }

        return $version->user_id == user_id() && $version->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given version.
     *
     * @param UserPolicy $user
     * @param Version $version
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Version $version)
    {
        return $version->user_id == user_id() && $version->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given version.
     *
     * @param UserPolicy $user
     * @param Version $version
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Version $version)
    {
        if ($user->canDo('compliancetype.version.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given version.
     *
     * @param UserPolicy $user
     * @param Version $version
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Version $version)
    {
        if ($user->canDo('compliancetype.version.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
